@@ -4,7 +4,7 @@
  * Line breaking in a Unicode sequence.  Designed to be used in a
  * generic text renderer.
  *
- * Copyright (C) 2008-2009 Wu Yongwei <wuyongwei at gmail dot com>
+ * Copyright (C) 2008-2010 Wu Yongwei <wuyongwei at gmail dot com>
  *
  * This software is provided 'as-is', without any express or implied
  * warranty.  In no event will the author be held liable for any damages
@@ -30,9 +30,9 @@
  * Unicode 5.0.0:
  *		<URL:http://www.unicode.org/reports/tr14/tr14-19.html>
  *
- * This library has been updated according to Revision 22, for
- * Unicode 5.1.0:
- *		<URL:http://www.unicode.org/reports/tr14/tr14-22.html>
+ * This library has been updated according to Revision 24, for
+ * Unicode 5.2.0:
+ *		<URL:http://www.unicode.org/reports/tr14/tr14-24.html>
  *
  * The Unicode Terms of Use are available at
  *		<URL:http://www.unicode.org/copyright.html>
@@ -44,7 +44,7 @@
  * Implementation of the line breaking algorithm as described in Unicode
  * Standard Annex 14.
  *
- * @version	1.2, 2009/04/29
+ * @version	2.0, 2010/01/03
  * @author	Wu Yongwei
  */
 
@@ -59,233 +59,164 @@
  */
 #define LINEBREAK_INDEX_SIZE 40
 
+/**
+ * Version number of the library.
+ */
+const int linebreak_version = LINEBREAK_VERSION;
+
 /**
  * Enumeration of break actions.  They are used in the break action
  * pair table below.
  */
 enum BreakAction
 {
-	DIRECT_BRK,			/**< Direct break opportunity */
-	INDIRECT_BRK,		/**< Indirect break opportunity */
-	CM_INDIRECT_BRK,	/**< Indirect break opportunity for combining marks */
-	CM_PROHIBITED_BRK,	/**< Prohibited break for combining marks */
-	PROHIBITED_BRK		/**< Prohibited break */
+	DIR_BRK,		/**< Direct break opportunity */
+	IND_BRK,		/**< Indirect break opportunity */
+	CMI_BRK,		/**< Indirect break opportunity for combining marks */
+	CMP_BRK,		/**< Prohibited break for combining marks */
+	PRH_BRK			/**< Prohibited break */
 };
 
 /**
  * Break action pair table.  This is a direct mapping of Table 2 of
- * Unicode Standard Annex 14, Revision 22.
-
+ * Unicode Standard Annex 14, Revision 24.
  */
 static enum BreakAction baTable[LBP_JT][LBP_JT] = {
 	{	/* OP */
-		PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK, CM_PROHIBITED_BRK,
-		PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		PROHIBITED_BRK, PROHIBITED_BRK },
+		PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, CMP_BRK,
+		PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK, PRH_BRK },
 	{	/* CL */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, PRH_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
+	{	/* CP */
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, PRH_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* QU */
-		PROHIBITED_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK },
+		PRH_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK,
+		IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK },
 	{	/* GL */
-		INDIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK,
+		IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK },
 	{	/* NS */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* EX */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* SY */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* IS */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, IND_BRK, IND_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* PR */
-		INDIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, IND_BRK, IND_BRK, IND_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK },
 	{	/* PO */
-		INDIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, IND_BRK, IND_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* NU */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* AL */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, IND_BRK, IND_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* ID */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* IN */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* HY */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, DIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, DIR_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* BA */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, DIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, DIR_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* BB */
-		INDIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK,
+		IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK },
 	{	/* B2 */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, IND_BRK, IND_BRK, DIR_BRK, PRH_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* ZW */
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, PRH_BRK, DIR_BRK,
+		DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* CM */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, DIR_BRK, IND_BRK, IND_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK },
 	{	/* WJ */
-		INDIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK },
+		IND_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK,
+		IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK },
 	{	/* H2 */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, IND_BRK, IND_BRK },
 	{	/* H3 */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, IND_BRK },
 	{	/* JL */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, DIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, IND_BRK, IND_BRK, IND_BRK, IND_BRK, DIR_BRK },
 	{	/* JV */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		INDIRECT_BRK, INDIRECT_BRK },
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, IND_BRK, IND_BRK },
 	{	/* JT */
-		DIRECT_BRK, PROHIBITED_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		INDIRECT_BRK, PROHIBITED_BRK, PROHIBITED_BRK, PROHIBITED_BRK,
-		DIRECT_BRK, INDIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK, INDIRECT_BRK,
-		DIRECT_BRK, DIRECT_BRK, PROHIBITED_BRK, CM_INDIRECT_BRK,
-		PROHIBITED_BRK, DIRECT_BRK, DIRECT_BRK, DIRECT_BRK,
-		DIRECT_BRK, INDIRECT_BRK }
+		DIR_BRK, PRH_BRK, PRH_BRK, IND_BRK, IND_BRK, IND_BRK, PRH_BRK,
+		PRH_BRK, PRH_BRK, DIR_BRK, IND_BRK, DIR_BRK, DIR_BRK, DIR_BRK,
+		IND_BRK, IND_BRK, IND_BRK, DIR_BRK, DIR_BRK, PRH_BRK, CMI_BRK,
+		PRH_BRK, DIR_BRK, DIR_BRK, DIR_BRK, DIR_BRK, IND_BRK }
 };
 
 /**
@@ -468,10 +399,8 @@ static enum LineBreakClass resolve_lb_class(
  * @param[in,out] ip	pointer to the index
  * @return				the Unicode character beginning at the index; or
  *						#EOS if end of input is encountered
- *
- * @deprecated	This function will be prefixed with \c lb_ in the future.
  */
-utf32_t get_next_char_utf8(
+utf32_t lb_get_next_char_utf8(
 		const utf8_t *s,
 		size_t len,
 		size_t *ip)
@@ -530,10 +459,8 @@ utf32_t get_next_char_utf8(
  * @param[in,out] ip	pointer to the index
  * @return				the Unicode character beginning at the index; or
  *						#EOS if end of input is encountered
- *
- * @deprecated	This function will be prefixed with \c lb_ in the future.
  */
-utf32_t get_next_char_utf16(
+utf32_t lb_get_next_char_utf16(
 		const utf16_t *s,
 		size_t len,
 		size_t *ip)
@@ -571,10 +498,8 @@ utf32_t get_next_char_utf16(
  * @param[in,out] ip	pointer to the index
  * @return				the Unicode character beginning at the index; or
  *						#EOS if end of input is encountered
- *
- * @deprecated	This function will be prefixed with \c lb_ in the future.
  */
-utf32_t get_next_char_utf32(
+utf32_t lb_get_next_char_utf32(
 		const utf32_t *s,
 		size_t len,
 		size_t *ip)
@@ -685,11 +610,11 @@ nextline:
 		assert(lbcNew <= LBP_JT);
 		switch (baTable[lbcCur - 1][lbcNew - 1])
 		{
-		case DIRECT_BRK:
+		case DIR_BRK:
 			brks[posLast] = LINEBREAK_ALLOWBREAK;
 			break;
-		case CM_INDIRECT_BRK:
-		case INDIRECT_BRK:
+		case CMI_BRK:
+		case IND_BRK:
 			if (lbcLast == LBP_SP)
 			{
 				brks[posLast] = LINEBREAK_ALLOWBREAK;
@@ -699,12 +624,12 @@ nextline:
 				brks[posLast] = LINEBREAK_NOBREAK;
 			}
 			break;
-		case CM_PROHIBITED_BRK:
+		case CMP_BRK:
 			brks[posLast] = LINEBREAK_NOBREAK;
 			if (lbcLast != LBP_SP)
 				continue;
 			break;
-		case PROHIBITED_BRK:
+		case PRH_BRK:
 			brks[posLast] = LINEBREAK_NOBREAK;
 			break;
 		}
@@ -738,7 +663,8 @@ void set_linebreaks_utf8(
 		const char *lang,
 		char *brks)
 {
-	set_linebreaks(s, len, lang, brks, (get_next_char_t)get_next_char_utf8);
+	set_linebreaks(s, len, lang, brks,
+				   (get_next_char_t)lb_get_next_char_utf8);
 }
 
 /**
@@ -757,7 +683,8 @@ void set_linebreaks_utf16(
 		const char *lang,
 		char *brks)
 {
-	set_linebreaks(s, len, lang, brks, (get_next_char_t)get_next_char_utf16);
+	set_linebreaks(s, len, lang, brks,
+				   (get_next_char_t)lb_get_next_char_utf16);
 }
 
 /**
@@ -776,7 +703,8 @@ void set_linebreaks_utf32(
 		const char *lang,
 		char *brks)
 {
-	set_linebreaks(s, len, lang, brks, (get_next_char_t)get_next_char_utf32);
+	set_linebreaks(s, len, lang, brks,
+				   (get_next_char_t)lb_get_next_char_utf32);
 }
 
 /**
@@ -791,12 +719,8 @@ void set_linebreaks_utf32(
  * @param lang  language of the input
  * @return      one of #LINEBREAK_MUSTBREAK, #LINEBREAK_ALLOWBREAK,
  *				#LINEBREAK_NOBREAK, or #LINEBREAK_INSIDEACHAR
- *
- * @deprecated  This function will be renamed to #is_line_breakable in
- * 				the future.  The name is already defined as a
- * 				macro&mdash;please use it.
  */
-int is_breakable(
+int is_line_breakable(
 		utf32_t char1,
 		utf32_t char2,
 		const char* lang)
